@@ -1,8 +1,18 @@
 """Constants used by ansible_compat."""
 
 
+REQUIREMENT_LOCATIONS = [
+    "requirements.yml",
+    "roles/requirements.yml",
+    "collections/requirements.yml",
+    # These is more of less the official way to store test requirements in collections so far, comments shows number of repos using this reported by https://sourcegraph.com/ at the time of writing
+    "tests/requirements.yml",  # 170
+    "tests/integration/requirements.yml",  # 3
+    "tests/unit/requirements.yml",  # 1
+]
+
 # Minimal version of Ansible we support for runtime
-ANSIBLE_MIN_VERSION = "2.9"
+ANSIBLE_MIN_VERSION = "2.12"
 
 # Based on https://docs.ansible.com/ansible/latest/reference_appendices/config.html
 ANSIBLE_DEFAULT_ROLES_PATH = (
@@ -26,3 +36,5 @@ Role: https://galaxy.ansible.com/docs/contributing/creating_role.html#role-names
 
 As an alternative, you can add 'role-name' to either skip_list or warn_list.
 """
+
+RC_ANSIBLE_OPTIONS_ERROR = 5
