@@ -1,5 +1,8 @@
 """Ansible runtime environment manager."""
+from __future__ import annotations
+
 import contextlib
+import fnmatch
 import importlib
 import json
 import logging
@@ -12,7 +15,7 @@ import warnings
 from collections import OrderedDict
 from dataclasses import dataclass, field
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Optional, Union, no_type_check
+from typing import TYPE_CHECKING, Any, Callable, no_type_check
 
 import subprocess_tee
 from packaging.version import Version
@@ -78,7 +81,7 @@ class CollectionVersion(Version):
 class Plugins:  # pylint: disable=too-many-instance-attributes
     """Dataclass to access installed Ansible plugins, uses ansible-doc to retrieve them."""
 
-    runtime: "Runtime"
+    runtime: Runtime
     become: dict[str, str] = field(init=False)
     cache: dict[str, str] = field(init=False)
     callback: dict[str, str] = field(init=False)
@@ -143,9 +146,9 @@ class Plugins:  # pylint: disable=too-many-instance-attributes
 class Runtime:
     """Ansible Runtime manager."""
 
-    _version: Optional[Version] = None
+    _version: Version | None = None
     collections: OrderedDict[str, Collection] = OrderedDict()
-    cache_dir: Optional[Path] = None
+    cache_dir: Path | None = None
     # Used to track if we have already initialized the Ansible runtime as attempts
     # to do it multiple tilmes will cause runtime warnings from within ansible-core
     initialized: bool = False
@@ -153,13 +156,13 @@ class Runtime:
 
     def __init__(
         self,
-        project_dir: Optional[Path] = None,
+        project_dir: Path | None = None,
         *,
         isolated: bool = False,
-        min_required_version: Optional[str] = None,
+        min_required_version: str | None = None,
         require_module: bool = False,
         max_retries: int = 0,
-        environ: Optional[dict[str, str]] = None,
+        environ: dict[str, str] | None = None,
     ) -> None:
         """Initialize Ansible runtime environment.
 
@@ -311,12 +314,12 @@ class Runtime:
 
     def run(  # ruff: disable=PLR0913
         self,
-        args: Union[str, list[str]],
+        args: str | list[str],
         *,
         retry: bool = False,
         tee: bool = False,
-        env: Optional[dict[str, str]] = None,
-        cwd: Optional[Path] = None,
+        env: dict[str, str] | None = None,
+        cwd: Path | None = None,
     ) -> CompletedProcess:
         """Execute a command inside an Ansible environment.
 
@@ -377,8 +380,8 @@ class Runtime:
 
     def version_in_range(
         self,
-        lower: Optional[str] = None,
-        upper: Optional[str] = None,
+        lower: str | None = None,
+        upper: str | None = None,
     ) -> bool:
         """Check if Ansible version is inside a required range.
 
@@ -392,9 +395,9 @@ class Runtime:
 
     def install_collection(
         self,
-        collection: Union[str, Path],
+        collection: str | Path,
         *,
-        destination: Optional[Path] = None,
+        destination: Path | None = None,
         force: bool = False,
     ) -> None:
         """Install an Ansible collection.
@@ -439,7 +442,7 @@ class Runtime:
     def install_collection_from_disk(
         self,
         path: Path,
-        destination: Optional[Path] = None,
+        destination: Path | None = None,
     ) -> None:
         """Build and install collection from a given disk path."""
         if not self.version_in_range(upper="2.11"):
@@ -550,9 +553,22 @@ class Runtime:
                     _logger.error(result.stderr)
                     raise AnsibleCommandError(result)
 
+    def search_galaxy_paths(self, search_dir: Path, depth: int = 0) -> list[str]:
+        """Search for galaxy paths (only one level deep)."""
+        galaxy_paths: list[str] = []
+        for file in os.listdir(search_dir):
+            file_path = Path(file)
+            if file_path.is_dir() and depth < 1:
+                galaxy_paths.extend(self.search_galaxy_paths(file_path, 1))
+            elif fnmatch.fnmatch(file, "galaxy.yml"):
+                galaxy_paths.append(str(search_dir / file))
+        if depth == 0 and not galaxy_paths:
+            return ["galaxy.yml"]
+        return galaxy_paths
+
     def prepare_environment(  # noqa: C901
         self,
-        required_collections: Optional[dict[str, str]] = None,
+        required_collections: dict[str, str] | None = None,
         *,
         retry: bool = False,
         install_local: bool = False,
@@ -560,7 +576,7 @@ class Runtime:
         role_name_check: int = 0,
     ) -> None:
         """Make dependencies available if needed."""
-        destination: Optional[Path] = None
+        destination: Path | None = None
         if required_collections is None:
             required_collections = {}
 
@@ -571,75 +587,82 @@ class Runtime:
         for req_file in REQUIREMENT_LOCATIONS:
             self.install_requirements(Path(req_file), retry=retry, offline=offline)
 
-        galaxy_path = Path("galaxy.yml")
-        if galaxy_path.exists():
-            data = yaml_from_file(galaxy_path)
-            if isinstance(data, dict) and "dependencies" in data:
-                for name, required_version in data["dependencies"].items():
-                    _logger.info(
-                        "Provisioning collection %s:%s from galaxy.yml",
-                        name,
-                        required_version,
-                    )
-                    self.install_collection(
-                        f"{name}:{required_version}",
-                        destination=destination,
-                    )
-
-        if self.cache_dir:
-            destination = self.cache_dir / "collections"
-        for name, min_version in required_collections.items():
-            self.install_collection(
-                f"{name}:>={min_version}",
-                destination=destination,
-            )
-
-        self._prepare_ansible_paths()
-
-        if not install_local:
-            return
-
-        if Path("galaxy.yml").exists():
-            if destination:
-                # while function can return None, that would not break the logic
-                colpath = Path(
-                    f"{destination}/ansible_collections/{colpath_from_path(Path.cwd())}",
-                )
-                if colpath.is_symlink():
-                    if os.path.realpath(colpath) == Path.cwd():
-                        _logger.warning(
-                            "Found symlinked collection, skipping its installation.",
+        for gpath in self.search_galaxy_paths(self.project_dir):
+            galaxy_path = Path(gpath)
+            if galaxy_path.exists():
+                data = yaml_from_file(galaxy_path)
+                if isinstance(data, dict) and "dependencies" in data:
+                    for name, required_version in data["dependencies"].items():
+                        _logger.info(
+                            "Provisioning collection %s:%s from galaxy.yml",
+                            name,
+                            required_version,
+                        )
+                        self.install_collection(
+                            f"{name}:{required_version}",
+                            destination=destination,
                         )
-                        return
-                    _logger.warning(
-                        "Collection is symlinked, but not pointing to %s directory, so we will remove it.",
-                        Path.cwd(),
-                    )
-                    colpath.unlink()
 
-            # molecule scenario within a collection
-            self.install_collection_from_disk(Path("."), destination=destination)
-        elif (
-            Path().resolve().parent.name == "roles"
-            and Path("../../galaxy.yml").exists()
-        ):
-            # molecule scenario located within roles/<role-name>/molecule inside
-            # a collection
-            self.install_collection_from_disk(Path("../.."), destination=destination)
-        else:
-            # no collection, try to recognize and install a standalone role
-            self._install_galaxy_role(
-                self.project_dir,
-                role_name_check=role_name_check,
-                ignore_errors=True,
-            )
+            if self.cache_dir:
+                destination = self.cache_dir / "collections"
+            for name, min_version in required_collections.items():
+                self.install_collection(
+                    f"{name}:>={min_version}",
+                    destination=destination,
+                )
+
+            self._prepare_ansible_paths()
+
+            if not install_local:
+                return
+
+            if galaxy_path.exists():
+                if destination:
+                    # while function can return None, that would not break the logic
+                    colpath = Path(
+                        f"{destination}/ansible_collections/{colpath_from_path(Path.cwd())}",
+                    )
+                    if colpath.is_symlink():
+                        if os.path.realpath(colpath) == Path.cwd():
+                            _logger.warning(
+                                "Found symlinked collection, skipping its installation.",
+                            )
+                            return
+                        _logger.warning(
+                            "Collection is symlinked, but not pointing to %s directory, so we will remove it.",
+                            Path.cwd(),
+                        )
+                        colpath.unlink()
+
+                # molecule scenario within a collection
+                self.install_collection_from_disk(
+                    galaxy_path.parent,
+                    destination=destination,
+                )
+            elif (
+                Path().resolve().parent.name == "roles"
+                and Path("../../galaxy.yml").exists()
+            ):
+                # molecule scenario located within roles/<role-name>/molecule inside
+                # a collection
+                self.install_collection_from_disk(
+                    Path("../.."),
+                    destination=destination,
+                )
+            else:
+                # no collection, try to recognize and install a standalone role
+                self._install_galaxy_role(
+                    self.project_dir,
+                    role_name_check=role_name_check,
+                    ignore_errors=True,
+                )
         # reload collections
         self.load_collections()
 
     def require_collection(
         self,
         name: str,
-        version: Optional[str] = None,
+        version: str | None = None,
         *,
         install: bool = True,
     ) -> None:
